/* See LICENSE for licensing and NOTICE for copyright. */
package edu.vt.middleware.ldap.ed;

import org.testng.AssertJUnit;
import org.testng.annotations.Test;

/**
 * Unit tests for multi-factor implementations.
 *
 * @author  Middleware Services
 */
public class LoginTest
{

  /**
   * Unit test for {@link Login}.
   *
   * @throws  Exception  On test errors.
   */
  @Test(groups = {"logintest"})
  public void testEdAuthMFA()
          throws Exception
  {
    final Login edmfa = new Login();
    AssertJUnit.assertEquals(edmfa.getType(), DirectoryType.LOGIN);
  }

  /**
   * Unit tests for {@link DuoFactor}.
   *
   * @throws  Exception  On test errors.
   */
  @Test(groups = {"logintest"})
  public void testDuoFactor()
          throws Exception
  {
    Throwable e = null;
    try {
      new DuoFactor(DuoFactor.Type.PASSCODE).getValue();
    } catch (IllegalArgumentException ex) {
      e = ex;
    }
    //Passcode must have value
    AssertJUnit.assertNotNull(e);

    e = null;
    try {
      new DuoFactor(DuoFactor.Type.PASSCODE, 13).getValue();
    } catch (IllegalArgumentException ex) {
      e = ex;
    }
    //Passcode cannot have index
    AssertJUnit.assertNotNull(e);

    e = null;
    try {
      new DuoFactor(DuoFactor.Type.AUTO, 13).getValue();
    } catch (IllegalArgumentException ex) {
      e = ex;
    }
    //Auto cannot have index
    AssertJUnit.assertNotNull(e);

    e = null;
    try {
      new DuoFactor(DuoFactor.Type.AUTO, "value").getValue();
    } catch (IllegalArgumentException ex) {
      e = ex;
    }
    //Auto cannot have value
    AssertJUnit.assertNotNull(e);

    e = null;
    try {
      new DuoFactor(DuoFactor.Type.SMS, "value").getValue();
    } catch (IllegalArgumentException ex) {
      e = ex;
    }
    //SMS cannot have value
    AssertJUnit.assertNotNull(e);

    e = null;
    try {
      new DuoFactor(DuoFactor.Type.PHONE, "value").getValue();
    } catch (IllegalArgumentException ex) {
      e = ex;
    }
    //PHONE cannot have value
    AssertJUnit.assertNotNull(e);

    e = null;
    try {
      new DuoFactor(DuoFactor.Type.PUSH, "value").getValue();
    } catch (IllegalArgumentException ex) {
      e = ex;
    }
    //PUSH cannot have value
    AssertJUnit.assertNotNull(e);

    AssertJUnit.assertEquals(",phone", new DuoFactor(DuoFactor.Type.PHONE).getValue());
    AssertJUnit.assertEquals(",phone", new DuoFactor(DuoFactor.Type.PHONE, 0).getValue());
    AssertJUnit.assertEquals(",phone1", new DuoFactor(DuoFactor.Type.PHONE, 1).getValue());
    AssertJUnit.assertEquals(",push", new DuoFactor(DuoFactor.Type.PUSH).getValue());
    AssertJUnit.assertEquals(",push", new DuoFactor(DuoFactor.Type.PUSH, 0).getValue());
    AssertJUnit.assertEquals(",push1", new DuoFactor(DuoFactor.Type.PUSH, 1).getValue());
    AssertJUnit.assertEquals(",auto", new DuoFactor(DuoFactor.Type.AUTO).getValue());
    AssertJUnit.assertEquals(",12345", new DuoFactor(DuoFactor.Type.PASSCODE, "12345").getValue());
    AssertJUnit.assertEquals(",sms2", new DuoFactor(DuoFactor.Type.SMS, 2).getValue());

  }

}
